************************
Rigado Sphinx Extensions
************************

- ``inventory-builder``: A shorter version of the HTML builder, that only outputs an inventory (e.g. for use with ``intersphinx``)
- ``tablelist``: Adds ``tablelist`` and ``figurelist`` directives to compile lists of tables and figures, respectively.
